# Example Package

This is a simple example package. You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.

## Distributing

- failed to use poetry to bundle - got `/Users/swyx/Desktop/Work/env-info/report_env does not contain any element` error and couldnt fix
- `python3 -m build`
- `python3 -m twine upload dist/*`


## thanks

- https://packaging.python.org/en/latest/tutorials/packaging-projects/
- https://github.com/cs01/pycowsay
